#include "FileSystemModel.h"

FileSystemModel::FileSystemModel( QObject* object )
{
	connect(this, SIGNAL(directoryLoaded(const QString &)), this, SLOT(directoryLoaded(const QString &)));
}

void FileSystemModel::directoryLoaded( const QString & path )
{
    QModelIndex idx = index( path );

    for( int i = 0; i < rowCount( idx ); i++ ) {
        QModelIndex child = index( i, 0, idx );

		if(!child.isValid()) {
			continue;
		}

        if( canFetchMore( child ) ) {
            fetchMore( child );
        }
    }
}

MainWindow::MainWindow( void )
{
	FileSystemModel* model = new FileSystemModel(this);
	model->setReadOnly(false);
	model->setRootPath( QDir::currentPath() );
	
	QTreeView* view = new QTreeView(this);
	view->setModel(model);
	view->setRootIndex(model->index(model->rootPath()));
	view->setHeaderHidden( true );
	view->setDragEnabled( true );
	view->setDropIndicatorShown( true );
	view->setDragDropOverwriteMode( true );
	view->setSelectionMode( QTreeView::ExtendedSelection );
	view->setDragDropMode( QTreeView::InternalMove );
	view->setEditTriggers( QTreeView::EditTrigger::EditKeyPressed );
	view->viewport()->setAcceptDrops( true );

	setCentralWidget(view);
}

int main(int argc, char *argv[])
{
	QCoreApplication::setLibraryPaths( QCoreApplication::libraryPaths() << "." << "imageformats" << "platforms" );
    QApplication app( argc, argv );

	MainWindow m;
	m.show();

    return app.exec();
}